@@ -148,7 +148,7 @@ class PPSMixin:
             job=pps_proto.Job(id=job_id), data_filters=data_filters,
         )
 
-    def create_pipeline(self, pipeline_name, transform=None, parallelism_spec=None,
+    def create_pipeline(self, pipeline_name, transform, parallelism_spec=None,
                         hashtree_spec=None, egress=None, update=None, output_branch=None,
                         scale_down_threshold=None, resource_requests=None,
                         resource_limits=None, input=None, description=None, cache_size=None,
@@ -164,7 +164,7 @@ class PPSMixin:
         Params:
 
         * `pipeline_name`: A string representing the pipeline name.
-        * `transform`: An optional `Transform` object.
+        * `transform`: A `Transform` object.
         * `parallelism_spec`: An optional `ParallelismSpec` object.
         * `hashtree_spec`: An optional `HashtreeSpec` object.
         * `egress`: An optional `Egress` object.
@@ -225,6 +225,85 @@ class PPSMixin:
             spec_commit=spec_commit,
         )
 
+    def create_tf_job_pipeline(self, pipeline_name, tf_job, parallelism_spec=None,
+                               hashtree_spec=None, egress=None, update=None, output_branch=None,
+                               scale_down_threshold=None, resource_requests=None,
+                               resource_limits=None, input=None, description=None, cache_size=None,
+                               enable_stats=None, reprocess=None, max_queue_size=None,
+                               service=None, chunk_spec=None, datum_timeout=None,
+                               job_timeout=None, salt=None, standby=None, datum_tries=None,
+                               scheduling_spec=None, pod_patch=None, spout=None, spec_commit=None):
+        """
+        Creates a pipeline. For more info, please refer to the pipeline spec
+        document:
+        http://docs.pachyderm.io/en/latest/reference/pipeline_spec.html
+
+        Params:
+
+        * `pipeline_name`: A string representing the pipeline name.
+        * `tf_job`: A `TFJob` object. Pachyderm uses this to create TFJobs
+        when running in a Kubernetes cluster on which kubeflow has been
+        installed.
+        * `parallelism_spec`: An optional `ParallelismSpec` object.
+        * `hashtree_spec`: An optional `HashtreeSpec` object.
+        * `egress`: An optional `Egress` object.
+        * `update`: An optional bool specifying whether this should behave as
+        an upsert.
+        * `output_branch`: An optional string representing the branch to output
+        results on.
+        * `scale_down_threshold`: An optional `Duration` object.
+        * `resource_requests`: An optional `ResourceSpec` object.
+        * `resource_limits`: An optional `ResourceSpec` object.
+        * `input`: An optional `Input` object.
+        * `description`: An optional string describing the pipeline.
+        * `cache_size`: An optional string.
+        * `enable_stats`: An optional bool.
+        * `reprocess`: An optional bool. If true, pachyderm forces the pipeline
+        to reprocess all datums. It only has meaning if `update` is `True`.
+        * `max_queue_size`: An optional int.
+        * `service`: An optional `Service` object.
+        * `chunk_spec`: An optional `ChunkSpec` object.
+        * `datum_timeout`: An optional `Duration` object.
+        * `job_timeout`: An optional `Duration` object.
+        * `salt`: An optional string.
+        * `standby`: An optional bool.
+        * `datum_tries`: An optional int.
+        * `scheduling_spec`: An optional `SchedulingSpec` object.
+        * `pod_patch`: An optional string.
+        * `spout`: An optional `Spout` object.
+        * `spec_commit`: An optional `Commit` object.
+        """
+        return self._req(
+            Service.PPS, "CreatePipeline",
+            pipeline=pps_proto.Pipeline(name=pipeline_name),
+            tf_job=tf_job,
+            parallelism_spec=parallelism_spec,
+            hashtree_spec=hashtree_spec,
+            egress=egress,
+            update=update,
+            output_branch=output_branch,
+            scale_down_threshold=scale_down_threshold,
+            resource_requests=resource_requests,
+            resource_limits=resource_limits,
+            input=input,
+            description=description,
+            cache_size=cache_size,
+            enable_stats=enable_stats,
+            reprocess=reprocess,
+            max_queue_size=max_queue_size,
+            service=service,
+            chunk_spec=chunk_spec,
+            datum_timeout=datum_timeout,
+            job_timeout=job_timeout,
+            salt=salt,
+            standby=standby,
+            datum_tries=datum_tries,
+            scheduling_spec=scheduling_spec,
+            pod_patch=pod_patch,
+            spout=spout,
+            spec_commit=spec_commit,
+        )
+
     def inspect_pipeline(self, pipeline_name, history=None):
         """
         Inspects a pipeline. Returns a `PipelineInfo` object.
